@@ -65,7 +65,12 @@ from kestrel.exceptions import (
 )
 from kestrel.syntax.parser import get_all_input_var_names
 from kestrel.syntax.parser import parse
-from kestrel.syntax.utils import get_keywords
+from kestrel.syntax.utils import (
+    get_entity_types,
+    all_relations,
+    LITERALS,
+    AGG_FUNCS,
+)
 from kestrel.semantics import *
 from kestrel.codegen import commands
 from kestrel.codegen.display import DisplayBlockSummary
@@ -390,14 +395,48 @@ class Session(object):
                 allnames = []
                 _logger.debug("cannot find auto-complete interface")
         else:
-            allnames = (
-                get_keywords()
-                + self.get_variable_names()
-                + self.data_source_manager.schemes()
-                + self.analytics_manager.schemes()
-            )
             _logger.debug("standard auto-complete")
 
+            try:
+                self.parse(prefix)
+
+                # If it parses successfully, add something so it will fail
+                self.parse(prefix + " @autocompletions@")
+            except KestrelSyntaxError as e:
+                tmp = []
+                for token in e.expected:
+                    if token == "VARIABLE":
+                        tmp.extend(self.get_variable_names())
+                    elif token == "DATASRC":
+                        schemes = self.data_source_manager.schemes()
+                        tmp.extend([f"{scheme}://" for scheme in schemes])
+                        tmp.extend(self.get_variable_names())
+                    elif token == "ANALYTICS":
+                        schemes = self.analytics_manager.schemes()
+                        tmp.extend([f"{scheme}://" for scheme in schemes])
+                    elif token == "ENTITY_TYPE":
+                        tmp.extend(get_entity_types())
+                    elif token.startswith("STIXPATH"):
+                        # TODO: figure out the varname and get its attrs
+                        continue
+                    elif token == "RELATION":
+                        tmp.extend(all_relations)
+                    elif token == "REVERSED":
+                        tmp.append("BY")
+                        varnames = self.get_variable_names()
+                        if last_word not in varnames:
+                            # Must be FIND and not GROUP
+                            tmp.extend(all_relations)
+                    elif token == "FUNCNAME":
+                        tmp.extend(AGG_FUNCS)
+                    elif token in LITERALS:
+                        continue
+                    elif token.startswith("__ANON"):
+                        continue
+                    else:
+                        tmp.append(token)
+                allnames = sorted(tmp)
+
         suggestions = [
             name[len(last_word) :] for name in allnames if name.startswith(last_word)
         ]
